Parse and resolve the Solidity source code provided in src, for the target chain as specified in target.
The result is a list of resolved contracts (if successful) and a list of compiler warnings, errors and
informational messages like found contact N.