Module codegen

Module codegen 

Modules

cfg
revert
Releated to code that ultimately compiles to the target equivalent instruction of EVM revert (0xfd).

Structs

Options

Enums

Builtin
Expression
HostFunctions
OptimizationLevel

Constants

MAXIMUM_ACCOUNT_SIZE
Maximum permitted size of account data (10 MiB). https://github.com/solana-labs/solana/blob/08aba38d3507c8cb66f85074d8f1249d43e64a75/sdk/program/src/system_instruction.rs#L85
SOLANA_FIRST_OFFSET
STORAGE_INITIALIZER
Name of the storage initializer function

Functions

codegen
The contracts are fully resolved but they do not have any CFGs which is needed for the llvm code emitter. This will also do additional code checks.