#[non_exhaustive]pub enum SolidityError {
Empty,
String(Expression),
Panic(PanicCode),
Custom {
error_no: usize,
exprs: Vec<Expression>,
},
}Expand description
Corresponds to the error types from the Solidity language.
Marked as non-exhaustive because Solidity may add more variants in the future.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
Reverts with “empty error data”; stems from revert() or require() without string arguments.
String(Expression)
The Error(string) selector
Panic(PanicCode)
The Panic(uint256) selector
Custom
User defined errors
Implementations
Sourceimpl SolidityError
impl SolidityError
Sourcepub fn selector_expression(&self, ns: &Namespace) -> Expression
pub fn selector_expression(&self, ns: &Namespace) -> Expression
Return the selector expression of the error.