pub struct ResolvedFile {
pub path: OsString,
pub full_path: PathBuf,
pub import_no: Option<usize>,
pub contents: Arc<str>,
}Expand description
When we resolve a file, we need to know its base compared to the import so we can resolve the next import, and the full path on the filesystem. Since the same filename can exists in multiple imports, we need to tell the user exactly which file has errors/warnings.
Fields
path: OsStringOriginal name used on cli or import statement
full_path: PathBufFull path on the filesystem
import_no: Option<usize>Which import path was used, if any
contents: Arc<str>The actual file contents